@@ -1,11 +1,11 @@
-import cStringIO, struct, collections, socket
+import cStringIO, struct, socket
 ###
 from rtypes import *
 from misc import FunctionMapper
 from rexceptions import RResponseError, REvalError
 from taggedContainers import TaggedList, asTaggedArray, asAttrArray
 
-DEBUG = 0
+DEBUG = False
 
 class Lexeme(list):
     def __init__(self, rTypeCode, length, hasAttr, lexpos):
@@ -181,13 +181,29 @@ class Lexer(object):
         # b can be 2, meaning NA. Otherwise transform 0/1 into False/True
         return None if b==2 else b==1
 
-    @fmap(XT_ARRAY_BOOL, XT_ARRAY_INT, XT_ARRAY_DOUBLE)
+    @fmap(XT_ARRAY_INT, XT_ARRAY_DOUBLE, XT_ARRAY_CPLX)
     def xt_array_numeric(self, lexeme):
         raw = self.read(lexeme.dataLength)
         # TODO: swapping...
         data = numpy.fromstring(raw, dtype=numpyMap[lexeme.rTypeCode])
         return data
 
+    @fmap(XT_ARRAY_BOOL)
+    def xt_array_bool(self, lexeme):
+        """A boolean array consists of a 4-byte word (i.e. integer) determining the number of boolean values
+        in the following dataLength-4 bytes.
+        E.g. a bool array of one TRUE item looks like:
+        01 00 00 00   01 ff ff ff
+
+        The first 01 value tells that there is one bool value in the array.
+        The other 01 is the TRUE value, the other 3 'ff's are padding bytes. Those will be used if the vector
+        has 2,3 or 4 boolean values. For a fifth value another 4 bytes are appended.
+        """
+        numBools = self.__unpack(XT_INT, 1)[0]
+        raw = self.read(lexeme.dataLength-4)  # read the actual boolean values, including padding bytes
+        data = numpy.fromstring(raw[:numBools], dtype=numpyMap[lexeme.rTypeCode])
+        return data
+
     @fmap(XT_ARRAY_STR)
     def xt_array_str(self, lexeme):
         '''
@@ -220,7 +236,7 @@ class Lexer(object):
 
     @fmap(XT_RAW)
     def xt_raw(self, lexeme):
-        numBytes = self.__unpack(XT_INT)
+        self.__unpack(XT_INT)
         return self.read(lexeme.dataLength - 4)
 
 
@@ -297,7 +313,7 @@ class RParser(object):
         if lexeme.hasAttr:
             self.indentLevel += 1
             if DEBUG:
-                print '%s Attribute:' % (self.__ind)
+                print '%s Attribute:' % self.__ind
             lexeme.setAttr(self._parseExpr())
             self.indentLevel -= 1
         lexeme.data = self.parserMap.get(lexeme.rTypeCode, self[None])(self, lexeme)
@@ -334,20 +350,15 @@ class RParser(object):
                     # the array has a defined shape
                     data.shape = value
                 elif tag == 'names':
-                    # convert numpy-vector 'value' into list to make taggedarray work properly:
+                    # convert numpy-vector 'value' into list to make TaggedArray work properly:
                     data = asTaggedArray(data, list(value))
                 else:
-                    # there are unknow tags in the attribute, just collect them in a dictionary
-                    # of the array. (if array is a plain numpy array we need to convert it into
-                    # a view to be able to store new attributes to it):
+                    # there are additional tags in the attribute, just collect them in a dictionary
+                    # attached to the array. 
                     try:
                         data.attr[tag] = value
                     except AttributeError:
                         data = asAttrArray(data, {tag: value})
-                        # make a subclass of the array class:
-                        #class AttrArray(_AttrArray, data.__class__): pass
-                        #data = data.view(AttrArray)
-                        #data.attr = {tag: value}
         return data
 
     @fmap(XT_VECTOR, XT_LANG_NOTAG, XT_LIST_NOTAG)
@@ -411,25 +422,6 @@ def rparse(src, atomicArray=False):
 
 ########################################################################################
 
-class _AttrArray(object):
-    '''
-    This class should not be used directly, but rather be used as a mixin class
-    when subclassing from a numpy class.
-    e.g.  
-    class RAttrClass(numpy.ndarray, AttrArray): 
-        pass
-    
-    Such a sub-class can be used to to store additional information in extra
-    attributes. (pure numpy arrays won't allow to create those).
-    '''
-    def __repr__(self):
-        r = super(_AttrArray, self).__repr__()
-        if hasattr(self, 'attr'):
-            return r[:-1] + ', attr=' + repr(self.attr) + ')'
-        return r
-
-    
-
 class Closure(object):
     'Very simple container to return "something" for a closure. Not really usable in Python though.'
     def __init__(self, lexeme, aList1, aList2):
